#ifndef GNOME_PROPERTIES_H
#define GNOME_PROPERTIES_H

BEGIN_GNOME_DECLS

typedef struct {
	GtkWidget *notebook;
} GnomePropertyConfigurator;

/* This is the first parameter to the callback function */
typedef enum {
	GNOME_PROPERTY_APPLY
} GnomePropertyRequest;

GnomePropertyConfigurator *gnome_property_configurator_new     (void);

void                      gnome_property_configurator_destroy  (GnomePropertyConfigurator *);

void                      gnome_property_configurator_register (GnomePropertyConfigurator *, 
							        GtkWidget *title_widget,
								GtkWidget *content_widget,
								int (*callback)(GnomePropertyRequest));
END_GNOME_DECLS

#endif
